@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::AnyThing;
-$Config::Model::AnyThing::VERSION = '2.082';
+$Config::Model::AnyThing::VERSION = '2.086';
 use Mouse;
 
 # FIXME: must cleanup warp mechanism to implement this
@@ -225,7 +225,7 @@ sub load_pod_annotation {
             my $note = $item->text . '';
             $note =~ s/\s+$//;
             $logger->debug("load_pod_annotation: '$path' -> '$note'");
-            $self->grab( step => $path )->annotation($note);
+            $self->grab( steps => $path )->annotation($note);
         }
     }
 }
@@ -241,12 +241,12 @@ sub load_pod_annotation {
 
 sub grab {
     my $self = shift;
-    my ( $step, $mode, $autoadd, $type, $grab_non_available, $check ) =
+    my ( $steps, $mode, $autoadd, $type, $grab_non_available, $check ) =
         ( undef, 'strict', 1, undef, 0, 'yes' );
 
-    my %args = @_ > 1 ? @_ : ( step => $_[0] );
+    my %args = @_ > 1 ? @_ : ( steps => $_[0] );
 
-    $step               = delete $args{step};
+    $steps               = delete $args{steps} // delete $args{step};
     $mode               = delete $args{mode} if defined $args{mode};
     $autoadd            = delete $args{autoadd} if defined $args{autoadd};
     $grab_non_available = delete $args{grab_non_available}
@@ -264,11 +264,11 @@ sub grab {
         message => "grab: unexpected parameter: " . join( ' ', keys %args ) ) if %args;
 
     Config::Model::Exception::Internal->throw(
-        error => "grab: step parameter must be a string " . "or an array ref" )
-        unless ref $step eq 'ARRAY' || not ref $step;
+        error => "grab: steps parameter must be a string " . "or an array ref" )
+        unless ref $steps eq 'ARRAY' || not ref $steps;
 
     # accept commands, grep remove empty items left by spurious spaces
-    my $huge_string = ref $step ? join( ' ', @$step ) : $step;
+    my $huge_string = ref $steps ? join( ' ', @$steps ) : $steps;
     my @command = (
         $huge_string =~ m/
          (         # begin of *one* command
@@ -462,7 +462,7 @@ COMMAND:
                 function      => 'grab',
                 got_type      => $found[-1]->get_type,
                 expected_type => $type,
-                info          => "requested with step '$step'"
+                info          => "requested with steps '$steps'"
             ) if $mode ne 'adaptative';
             pop @found;
         }
@@ -475,7 +475,7 @@ COMMAND:
 
 sub grab_value {
     my $self = shift;
-    my %args = scalar @_ == 1 ? ( step => $_[0] ) : @_;
+    my %args = scalar @_ == 1 ? ( steps => $_[0] ) : @_;
 
     my $obj = $self->grab(%args);
 
@@ -505,7 +505,7 @@ sub grab_value {
 
 sub grab_annotation {
     my $self = shift;
-    my @args = scalar @_ == 1 ? ( step => $_[0] ) : @_;
+    my @args = scalar @_ == 1 ? ( steps => $_[0] ) : @_;
 
     my $obj = $self->grab(@args);
 
@@ -563,6 +563,13 @@ sub grab_ancestor_with_element_named {
     }
 }
 
+# fallback method for object that don't implement has_data
+sub has_data {
+    my $self= shift;
+    $logger->debug("called fall-back has_data for element", $self->name) if $logger->is_debug;
+    return 1;
+}
+
 sub model_searcher {
     my $self = shift;
     my %args = @_;
@@ -648,7 +655,7 @@ Config::Model::AnyThing - Base class for configuration tree item
 
 =head1 VERSION
 
-version 2.082
+version 2.086
 
 =head1 SYNOPSIS
 
@@ -759,7 +766,7 @@ Parameters are:
 
 =over
 
-=item C<step>
+=item C<steps> (or C<step>)
 
 A string indicating the steps to follow in the tree to find the
 required item. (mandatory)
@@ -768,7 +775,7 @@ required item. (mandatory)
 
 When set to C<strict>, C<grab> will throw an exception if no object is found
 using the passed string. When set to C<adaptative>, the object found at last will
-be returned. For instance, for the step C<good_step wrong_step>, only
+be returned. For instance, for the steps C<good_step wrong_step>, only
 the object held by C<good_step> will be returned. When set to C<loose>, grab 
 will return undef in case of problem. (default is C<strict>)
 
@@ -782,8 +789,8 @@ throw an exception or return the last found object of requested type.
 
 Examples:
 
- $root->grep(step => 'foo:2 bar', type => 'leaf')
- $root->grep(step => 'foo:2 bar', type => ['leaf','check_list'])
+ $root->grep(steps => 'foo:2 bar', type => 'leaf')
+ $root->grep(steps => 'foo:2 bar', type => ['leaf','check_list'])
 
 =item C<autoadd>
 
@@ -797,7 +804,7 @@ available. I.e. even if this element was warped out. (default is 0).
 
 =back
 
-The C<step> parameters is made of the following items separated by
+The C<steps> parameters is made of the following items separated by
 spaces:
 
 =over 8
