@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::Json;
-$Config::Model::Backend::Json::VERSION = '2.082';
+$Config::Model::Backend::Json::VERSION = '2.086';
 use Carp;
 use strict;
 use warnings;
@@ -93,7 +93,7 @@ Config::Model::Backend::Json - Read and write config as a JSON data structure
 
 =head1 VERSION
 
-version 2.082
+version 2.086
 
 =head1 SYNOPSIS
 
@@ -131,9 +131,9 @@ version 2.082
 
  my $root = $inst->config_root ;
 
- my $step = 'foo=yada bar="bla bla" baz:en=hello
+ my $steps = 'foo=yada bar="bla bla" baz:en=hello
              baz:fr=bonjour baz:hr="dobar dan"';
- $root->load( step => $step ) ;
+ $root->load( steps => $steps ) ;
  $inst->write_back ;
 
 Now, C</tmp/foo.yml> contains:
