@@ -9,7 +9,7 @@
 #
 
 package Config::Model::Backend::Yaml;
-$Config::Model::Backend::Yaml::VERSION = '2.082';
+$Config::Model::Backend::Yaml::VERSION = '2.086';
 use Carp;
 use strict;
 use warnings;
@@ -87,11 +87,6 @@ sub write {
 
     my $perl_data = $target->dump_as_data( full_dump => $args{full_dump} // 0);
 
-    my $size = ref($perl_data) eq 'HASH'  ? scalar keys %$perl_data
-             : ref($perl_data) eq 'ARRAY' ? scalar @$perl_data
-             :                              $perl_data ;
-    return 2 unless $size ;
-
     my $yaml = Dump $perl_data ;
 
     $args{io_handle}->print($yaml);
@@ -115,7 +110,7 @@ Config::Model::Backend::Yaml - Read and write config as a YAML data structure
 
 =head1 VERSION
 
-version 2.082
+version 2.086
 
 =head1 SYNOPSIS
 
@@ -153,9 +148,9 @@ version 2.082
 
  my $root = $inst->config_root ;
 
- my $step = 'foo=yada bar="bla bla" baz:en=hello
+ my $steps = 'foo=yada bar="bla bla" baz:en=hello
              baz:fr=bonjour baz:hr="dobar dan"';
- $root->load( step => $step ) ;
+ $root->load( steps => $steps ) ;
  $inst->write_back ;
 
 Now, C</tmp/foo.yml> contains:
