@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::CheckList;
-$Config::Model::CheckList::VERSION = '2.082';
+$Config::Model::CheckList::VERSION = '2.086';
 use Mouse;
 use 5.010;
 
@@ -362,6 +362,12 @@ sub uncheck {
         unless $self->instance->initial_load;
 }
 
+sub has_data {
+    my $self = shift;
+    my @set = $self->get_checked_list(qw/mode custom/) ;
+    return scalar @set;
+}
+
 my %accept_mode =
     map { ( $_ => 1 ) } qw/custom standard preset default layered upstream_default user/;
 
@@ -738,7 +744,7 @@ Config::Model::CheckList - Handle check list element
 
 =head1 VERSION
 
-version 2.082
+version 2.086
 
 =head1 SYNOPSIS
 
@@ -768,7 +774,7 @@ version 2.082
  my $root = $inst->config_root;
 
  # put data
- $root->load( step => 'my_check_list=A' ); 
+ $root->load( steps => 'my_check_list=A' );
 
  my $obj = $root->grab('my_check_list');
 
@@ -925,7 +931,7 @@ checklist will be available.
 
 This other hash or other checklist is indicated by the C<refer_to> or
 C<computed_refer_to> parameter. C<refer_to> uses the syntax of the
-C<step> parameter of L<grab(...)|Config::AnyThing/"grab(...)">
+C<steps> parameter of L<grab(...)|Config::AnyThing/"grab(...)">
 
 See L<refer_to parameter|Config::Model::IdElementReference/"refer_to parameter">.
 
@@ -1022,6 +1028,11 @@ choice value: either die (if yes) or discard bad value (if skip)
 
 C<mode> is either: custom standard preset default layered upstream_default
 
+=head2 has_data
+
+Return true if the check_list contains a set of checks different from default
+or upstream default set of check.
+
 =head2 get_choice
 
 Returns an array of all items names that can be checked (i.e.
@@ -1057,7 +1068,10 @@ With a parameter, this method will return either:
 
 =item custom
 
-The list entered by the user
+The list entered by the user. An empty list is returned if the list of
+checked items is identical to the list of items checked by default. The
+whole list of checked items is returned as soon as B<one> item is different
+from standard value.
 
 =item preset
 
