@@ -9,7 +9,7 @@
 #
 
 package Config::Model::Describe;
-$Config::Model::Describe::VERSION = '2.082';
+$Config::Model::Describe::VERSION = '2.086';
 use Carp;
 use strict;
 use warnings;
@@ -174,7 +174,7 @@ Config::Model::Describe - Provide a description of a node element
 
 =head1 VERSION
 
-version 2.082
+version 2.086
 
 =head1 SYNOPSIS
 
@@ -216,9 +216,9 @@ version 2.082
  my $root = $inst->config_root ;
 
  # put data
- my $step = 'foo=FOO hash_of_nodes:fr foo=bonjour -
+ my $steps = 'foo=FOO hash_of_nodes:fr foo=bonjour -
    hash_of_nodes:en foo=hello ';
- $root->load( step => $step );
+ $root->load( steps => $steps );
 
  print $root->describe ;
 
