@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Instance;
-$Config::Model::Instance::VERSION = '2.082';
+$Config::Model::Instance::VERSION = '2.086';
 #use Scalar::Util qw(weaken) ;
 
 use 5.10.1;
@@ -29,8 +29,7 @@ use Config::Model::SearchElement;
 use Config::Model::Iterator;
 use Config::Model::ObjTreeScanner;
 
-use warnings FATAL => qw(all);
-use warnings::register;
+use warnings ;
 
 use Carp qw/carp croak confess cluck/;
 
@@ -247,6 +246,8 @@ has tree => (
 sub reset_config {
     my $self = shift;
 
+    warn "skip_read is deprecated" if $self->skip_read;
+
     return $self->load_node (
         config_class_name => $self->{root_class_name},
         instance          => $self,
@@ -346,11 +347,20 @@ sub _stuff_clear {
 
 }
 
+sub modify {
+    my $self = shift ;
+    my %args   = @_ eq 1 ? ( step => $_[0] ) : @_;
+    my $force = delete $args{force_save} || delete $args{force};
+    $self->load(%args)->write_back( force => $force );
+    return $self;
+}
+
 sub load {
     my $self   = shift;
     my $loader = Config::Model::Loader->new;
     my %args   = @_ eq 1 ? ( step => $_[0] ) : @_;
     $loader->load( node => $self->{tree}, %args );
+    return $self;
 }
 
 sub search_element {
@@ -462,6 +472,14 @@ sub write_back {
     my $force_backend = delete $args{backend} || $self->{backend};
     my $force_write   = delete $args{force}   || 0;
 
+    # make sure that root node is loaded
+    $self->config_root->init;
+
+    if ($force_write) {
+        # make sure that the whole tree is loaded
+        my $dump = $self->config_root->dump_tree;
+    }
+
     foreach ( keys %args ) {
         if (/^(root|config_dir)$/) {
             $args{$_} ||= '';
@@ -472,8 +490,13 @@ sub write_back {
         }
     }
 
-    croak "write_back: no subs registered in instance $self->{name}. cannot save data\n"
-        unless @{ $self->{_write_back} };
+    if (not @{ $self->{_write_back} }) {
+        my $info = $self->application ? "the model of application ".$self->application
+            : "model ".$self->root_cladd_name ;
+        croak "Don't know how to save data of $self->{name} instance. Either $info has no configured ",
+            "read/write backend or no node containing a backend was loaded. ",
+            "Try with -force option or add read/write backend to $info\n";
+    }
 
     foreach my $path ( @{ $self->{_write_back} } ) {
         $logger->info("write_back called on node $path");
@@ -489,6 +512,10 @@ sub write_back {
     $self->clear_changes;
 }
 
+sub save {
+    goto &write_back;
+}
+
 sub update {
     my ($self, %args) = @_;
 
@@ -530,7 +557,7 @@ Config::Model::Instance - Instance of configuration tree
 
 =head1 VERSION
 
-version 2.082
+version 2.086
 
 =head1 SYNOPSIS
 
@@ -564,16 +591,25 @@ version 2.082
 
 =head1 DESCRIPTION
 
-This module provides an object that holds a configuration tree. 
+This module provides an object that holds a configuration tree.
 
 =head1 CONSTRUCTOR
 
-An instance object is created by calling 
-L<instance method|Config::Model/"Configuration instance"> on 
-an existing model:
+An instance object is created by calling L<instance
+method|Config::Model/"Configuration instance"> on an existing
+model. This model can be specified by its application name:
 
- my $inst = $model->instance (root_class_name => 'SomeRootClass', 
-                              instance_name => 'test1');
+ my $inst = $model->instance (
+   # run 'cme list' to get list of applications
+   application => 'foo',
+   # optional
+   instance_name => 'test1'
+ );
+
+ my $inst = $model->instance (
+   root_class_name => 'SomeRootClass',
+   instance_name => 'test1'
+ );
 
 The directory (or directories) holding configuration files is
 specified within the configuration model. For test purpose you can
@@ -598,8 +634,8 @@ Specify which backend to use. See L</write_back ( ... )> for details
 
 =item skip_read
 
-When set, configuration files will not be read when creating
-configuration tree.
+DEPRECATED. When set, configuration files will not be read when
+creating configuration tree.
 
 =item check
 
@@ -719,7 +755,14 @@ Get initial_load mode
 The data method provide a way to store some arbitrary data in the
 instance object.
 
-=head2 load( "..." )
+=head2 modify ( ... )
+
+Calls L</"load(...)"> and then L</save>.
+
+Takes the same parameter as C<load> plus C<force_write> to force
+saving configuration file even if no value was modified (default is 0)
+
+=head2 load ( ... )
 
 Load configuration tree with configuration data. See
 L<Config::Model::Loader> for more details
@@ -774,11 +817,20 @@ C<write_back> method.
 Notify that some data has changed in the tree. See
 L<Config::Model::AnyThing/notify_change(...)> for more details.
 
+=head2 save ( ... )
+
+Save the content of the configuration tree to
+configuration files. (alias to C<write_back>)
+
 =head2 write_back ( ... )
 
-Try to run all subroutines registered with C<register_write_back> to
-write the configuration information until one succeeds (returns
-true). (See L<Config::Model::BackendMgr> for details).
+In summary, save the content of the configuration tree to
+configuration files.
+
+In more details, C<write_back> trie to run all subroutines registered
+with C<register_write_back> to write the configuration information
+until one succeeds (returns true). (See L<Config::Model::BackendMgr>
+for details).
 
 You can specify here a pseudo root directory or another config
 directory to write configuration data back with C<root> and
