@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Utils::GenClassPod;
-$Config::Model::Utils::GenClassPod::VERSION = '2.082';
+$Config::Model::Utils::GenClassPod::VERSION = '2.086';
 # ABSTRACT: generate pod documentation from configuration models
 
 use strict;
@@ -23,6 +23,7 @@ use Config::Model ;             # to generate doc
 
 sub gen_class_pod {
     my $cm = Config::Model -> new(model_dir => "lib/Config/Model/models") ;
+    my %done;
 
     my @models = @_ ? @_ :
         map { /model\s*=\s*([\w:-]+)/; $1; }
@@ -32,13 +33,11 @@ sub gen_class_pod {
         path ("lib/Config/Model/")->children(qr/\.d$/);
 
     foreach my $model (@models) {
-        # this test avoid generating doc several times (generate_doc scan docs for
+        # %done avoid generating doc several times (generate_doc scan docs for
         # classes referenced by the model with config_class_name parameter)
-        if (not $cm->model_exists($model)) {
-            print "Checking doc for model $model\n";
-            $cm->load($model) ;
-            $cm->generate_doc ($model,'lib') ;
-        }
+        print "Checking doc for model $model\n";
+        $cm->load($model) ;
+        $cm->generate_doc ($model,'lib', \%done) ;
     }
 }
 
@@ -56,7 +55,7 @@ Config::Model::Utils::GenClassPod - generate pod documentation from configuratio
 
 =head1 VERSION
 
-version 2.082
+version 2.086
 
 =head1 SYNOPSIS
 
@@ -73,7 +72,7 @@ This module provides a single exported function: C<gen_class_pod>.
 
 This function will scan C<./lib/Config/Model/models/*.d>
 and generate pod documentation for each file found there using
-L<Config::Model::generate_doc|Config::Model/"generate_doc ( top_class_name , [ directory ] )">
+L<Config::Model::generate_doc|Config::Model/"generate_doc ( top_class_name , directory , [ \%done ] )">
 
 You can also pass one or more class names. C<gen_class_pod> will write
 the documentation for each passed class and all other classes used by
